Commit 9d222e8c authored by Andrey Filippov's avatar Andrey Filippov
Browse files

Scaled texture margins by 0.875

parent 35987171
Loading
Loading
Loading
Loading
+4 −4
Original line number Original line Diff line number Diff line
@@ -3582,7 +3582,7 @@ extern "C" __global__ void textures_accumulate( // (8,4,1) (N,1,1)
					texture_averaging[0] /= 64; // average value for uniform field
					texture_averaging[0] /= 64; // average value for uniform field
				}
				}
				__syncthreads();
				__syncthreads();
				float avg_val = texture_averaging[0];
				float avg_val = texture_averaging[0] *0.875;
				// now add scale average value for each missing direction
				// now add scale average value for each missing direction
				for (int idir = 0; idir < 8; idir ++) if ((alpha_mode & (1 << idir)) == 0) { // no tile in this direction
				for (int idir = 0; idir < 8; idir ++) if ((alpha_mode & (1 << idir)) == 0) { // no tile in this direction
					/* */
					/* */
@@ -3710,7 +3710,7 @@ extern "C" __global__ void textures_accumulate( // (8,4,1) (N,1,1)
							texture_averaging[0] /= 64; // average value for uniform field
							texture_averaging[0] /= 64; // average value for uniform field
						}
						}
						__syncthreads();
						__syncthreads();
						float avg_val = texture_averaging[0];
						float avg_val = texture_averaging[0] *0.875;


						// Possible to re-use ports_rgb_shared[], if needed (change to (calc_extra | (keep_weights & 2) in tile_combine_rgba()).
						// Possible to re-use ports_rgb_shared[], if needed (change to (calc_extra | (keep_weights & 2) in tile_combine_rgba()).
						// Now using averaging here (less noise if averaging sensor outside).
						// Now using averaging here (less noise if averaging sensor outside).